''
'' This code is part of https://developer.mescius.com/document-solutions/dot-net-pdf-api/demos.
'' Copyright (c) MESCIUS inc. All rights reserved.
''
Imports System
Imports System.IO
Imports System.Reflection
Imports System.Collections.Generic
Imports System.Diagnostics
Imports GrapeCity.Documents.Pdf
Imports GrapeCity.Documents.Pdf.Layers
''
'' This program creates an instance of the InkAnnotPaths class and uses it to generate a PDF file.
'' It also saves the generated PDF as TIFF (other supported formats are JPEG, PNG, BMP and GIF).
'' The packages needed to build and run this demo are available on NuGet.org.
''
'' Command line switches:
'' /y, -y -- assume all defaults, overwrite existing files.
'' /q, -q -- quiet operation (ignored unless /y is specified).
'' /n, -n -- generate repeatable 'random' data.
'' /f path, -f path -- use 'name' as base file path/name.
''
Module Program
    Sub Main(args As String())
        Dim yes2all = False
        Dim quiet = False
        Dim norandom = False
        Dim outMs As MemoryStream = Nothing
        Dim outTw As TextWriter = Nothing
        Try
            Dim fname = "InkAnnotPaths"
            For i = 0 to args.Length - 1
                Select Case args(i).ToLowerInvariant()
                    Case "/y", "-y"
                        yes2all = True
                    Case "/q", "-q"
                        quiet = True
                    Case "/n", "-n"
                        norandom = True
                    Case "/f", "-f"
                        If i + 1 < args.Length Then
                            i += 1
                            If Directory.Exists(args(i)) Then
                                fname = Path.Combine(args(i), fname)
                            Else
                                fname = args(i)
                            End If
                        End If
                End Select
            Next i
            If norandom Then
                Util.NoRandom = True
            End If
            If Not yes2all Then
                quiet = False
            End If
            If quiet Then
                outMs = New MemoryStream()
                outTw = New StreamWriter(outMs)
                Console.SetOut(outTw)
            End If

            Dim lk = Environment.GetEnvironmentVariable("DOCSOL_LKEY")
            if Not String.IsNullOrEmpty(lk) Then
                GcPdfDocument.SetLicenseKey(lk)
            End If

            Dim pdfName = Path.ChangeExtension(fname, ".pdf")
            Dim tiffName = Path.ChangeExtension(fname, ".tiff")
            Dim svgName = Path.ChangeExtension(fname, ".svg")

            If Not yes2all Then
                Console.WriteLine($"Press ENTER to create '{pdfName}' or enter an alternative file name:")
                Dim t = Console.ReadLine()
                If Not String.IsNullOrWhiteSpace(t) Then
                    pdfName = t
                End If
                pdfName = Path.GetFullPath(pdfName)
                If (File.Exists(pdfName)) Then
                    Console.WriteLine($"'{pdfName}' exists.{vbLf}OVERWRITE (Y/n)?")
                    Dim yesno = Console.ReadLine()
                    If yesno.ToLower() = "n" Then
                        Console.WriteLine("Aborted.")
                        Return
                    End If
                End If
            End If
            If Not quiet Then
                Console.WriteLine($"Generating '{pdfName}'...")
            End If
            Dim sample = New InkAnnotPaths()

            Using fs = New FileStream(pdfName, FileMode.Create)
                sample.CreatePDF(fs)
                If Not quiet Then
                    Console.WriteLine($"Created '{pdfName}' successfully.")
                End If
                If Not yes2all Then
                    '' Get the TIFF name:
                    Console.WriteLine($"Press ENTER to create '{tiffName}' or enter an alternative file name:")
                    Dim t = Console.ReadLine()
                    If Not String.IsNullOrWhiteSpace(t) Then
                        tiffName = t
                    End If
                    tiffName = Path.GetFullPath(tiffName)
                    If (File.Exists(tiffName)) Then
                        Console.WriteLine($"'{tiffName}' exists.{vbLf}OVERWRITE (Y/n)?")
                        Dim yesno = Console.ReadLine()
                        If yesno.ToLower() = "n" Then
                            Console.WriteLine("Aborted.")
                            Return
                        End If
                    End If
                    '' Get the SVG name:
                    Console.WriteLine($"Press ENTER to create '{svgName}' or enter an alternative file name:")
                    t = Console.ReadLine()
                    If Not String.IsNullOrWhiteSpace(t) Then
                        svgName = t
                    End If
                    svgName = Path.GetFullPath(svgName)
                    If (File.Exists(svgName)) Then
                        Console.WriteLine($"'{svgName}' exists.{vbLf}OVERWRITE (Y/n)?")
                        Dim yesno = Console.ReadLine()
                        If yesno.ToLower() = "n" Then
                            Console.WriteLine("Aborted.")
                            Return
                        End If
                    End If
                End If
                If Not quiet Then
                    Console.WriteLine($"Generating '{tiffName}'...")
                End If
                fs.Seek(0, SeekOrigin.Begin)
                Dim pdf = New GcPdfDocument()
                '' NOTE: up to 5 pages will be loaded if DsPdf is not licensed:
                pdf.Load(fs)
                '' Create default view state so that the default layers configuration is used in exports:
                Dim vs = New ViewState(pdf)
                '' Document pages can be also saved to other supported image formats,
                '' see GcPdfDocument.SaveAs<format> or Page.SaveAs<format> for details:
                pdf.SaveAsTiff(tiffName, vs)
                If Not quiet Then
                    Console.WriteLine($"Created '{tiffName}' successfully.")
                    Console.WriteLine($"Generating '{svgName}'...")
                End If
                '' Save as SVG:
                pdf.Pages(0).SaveAsSvg(svgName, vs)
                If Not quiet Then
                    Console.WriteLine($"Created '{svgName}' successfully.")
                End If
            End Using

            '' Uncomment to open the generated file:
            '' Dim psi = new ProcessStartInfo() With { .FileName = pdfName, .UseShellExecute = true }
            '' Process.Start(psi)

            '' Uncomment to open the generated TIFF file:
            '' Dim psiTiff = new ProcessStartInfo() With { .FileName = tiffName, .UseShellExecute = true }
            '' Process.Start(psiTiff)

            '' Uncomment to open the generated SVG file:
            '' Dim psiSvg = new ProcessStartInfo() With { .FileName = svgName, .UseShellExecute = true }
            '' Process.Start(psiSvg)
        Catch ex As Exception
            Console.Error.WriteLine($"Error: {ex.Message}")
            If ex.InnerException IsNot Nothing Then
                Console.Error.WriteLine($"InnerException: {ex.InnerException.Message}")
            End If
        Finally
            If Not yes2all Then
                Console.WriteLine("Press any key to exit...")
                Console.ReadKey()
            End If
            If quiet Then
                outTw.Dispose()
                outMs.Dispose()
            End If
        End Try
    End Sub
End Module
